// ============================================================================
/*!
 *	@file		MsDebugPrint.cs
 *	@brief		デバッグ表示
 *	@author		nyamo
 */
// ============================================================================
using System;
using System.Collections.Generic;

using Sce.Pss.Core;
using Sce.Pss.Core.Imaging;

namespace MsLib
{
	// ========================================================================
	//! デバッグ表示クラス
	// ========================================================================
	public class MsDebugPrint
	{
		struct DebugString {
			string		text;
			uint		color;
			int			px;
			int			py;

			public DebugString(string str, uint col, int x, int y)
			{
				text	= str;
				color	= col;
				px		= x;
				py		= y;
			}

			public string Text {
				get { return text;  }
				set { text = value; }
			}

			public uint Color {
				get { return color;  }
				set { color = value; }
			}

			public int PosX {
				get { return px;  }
				set { px = value; }
			}

			public int PosY {
				get { return py;  }
				set { py = value; }
			}
		};

		private static bool					isInit = false;
		private static List<DebugString>	debugStrList = new List<DebugString>();
		private static Font					debugFont;

		// --------------------------------------------------------------------
		//! 初期化
		// --------------------------------------------------------------------
		public static bool Init()
		{
			debugFont = new Font(FontAlias.System, 18, FontStyle.Regular);
			isInit = true;
			return true;
		}

		// --------------------------------------------------------------------
		//! 終了処理
		// --------------------------------------------------------------------
		public static void Term()
		{
			debugStrList.Clear();
			debugFont.Dispose();			
			isInit = false;
		}

		// --------------------------------------------------------------------
		//! クリア
		// --------------------------------------------------------------------
		public static void Clear()
		{
			debugStrList.Clear();
		}

		// --------------------------------------------------------------------
		//! 登録
		// --------------------------------------------------------------------
		public static void Print(string str, uint color, int x, int y)
		{
			debugStrList.Add(new DebugString(str, color, x, y));
		}

		// --------------------------------------------------------------------
		//! 描画
		// --------------------------------------------------------------------
		public static void Draw()
		{
			if (isInit == false) return;

#if DEBUG
			foreach (var s in debugStrList) {
				MsDraw.DrawSprite(new MsSprite(s.Text, s.Color, debugFont, s.PosX, s.PosY));
			}
#endif
		}
	}
}

